==> v1.0.13.tar.gz: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/session/room/membership/joining/InviteTask.kt <==
/*
 * Copyright 2020 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.session.room.membership.joining

import org.matrix.android.sdk.internal.network.executeRequest
import org.matrix.android.sdk.internal.session.room.RoomAPI
import org.matrix.android.sdk.internal.task.Task
import org.greenrobot.eventbus.EventBus
import javax.inject.Inject

internal interface InviteTask : Task<InviteTask.Params, Unit> {
    data class Params(
            val roomId: String,
            val userId: String,
            val reason: String?
    )
}

internal class DefaultInviteTask @Inject constructor(
        private val roomAPI: RoomAPI,
        private val eventBus: EventBus
) : InviteTask {

    override suspend fun execute(params: InviteTask.Params) {
        return executeRequest(eventBus) {
            val body = InviteBody(params.userId, params.reason)
            apiCall = roomAPI.invite(params.roomId, body)
            isRetryable = true
            maxRetryCount = 3
        }
    }
}

==> v1.1.0.tar.gz: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/session/room/membership/joining/InviteTask.kt <==
/*
 * Copyright 2020 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.session.room.membership.joining

import org.matrix.android.sdk.internal.network.GlobalErrorReceiver
import org.matrix.android.sdk.internal.network.executeRequest
import org.matrix.android.sdk.internal.session.room.RoomAPI
import org.matrix.android.sdk.internal.task.Task
import javax.inject.Inject

internal interface InviteTask : Task<InviteTask.Params, Unit> {
    data class Params(
            val roomId: String,
            val userId: String,
            val reason: String?
    )
}

internal class DefaultInviteTask @Inject constructor(
        private val roomAPI: RoomAPI,
        private val globalErrorReceiver: GlobalErrorReceiver
) : InviteTask {

    override suspend fun execute(params: InviteTask.Params) {
        return executeRequest(globalErrorReceiver) {
            val body = InviteBody(params.userId, params.reason)
            apiCall = roomAPI.invite(params.roomId, body)
            isRetryable = true
            maxRetryCount = 3
        }
    }
}
